@@ -6,16 +6,16 @@ import base64
 import json
 import logging
 from collections import OrderedDict
+from urllib.parse import urlencode
 
 import requests
 
-from bzt import TaurusNetworkError, ManualShutdown, VERSION, TaurusException
-from bzt.six import string_types
-from bzt.six import text_type
-from bzt.six import urlencode
+from bzt import TaurusNetworkError, ManualShutdown, TaurusException
 from bzt.utils import to_json, MultiPartForm
+from bzt.resources.version import VERSION
 
 BZA_TEST_DATA_RECEIVED = 100
+ENDED = 140
 
 
 class BZAObject(dict):
@@ -64,9 +64,9 @@ class BZAObject(dict):
         has_auth = headers and "X-Api-Key" in headers
         if has_auth:
             pass  # all is good, we have auth provided
-        elif isinstance(self.token, string_types) and ':' in self.token:
+        elif isinstance(self.token, str) and ':' in self.token:
             token = self.token
-            if isinstance(token, text_type):
+            if isinstance(token, str):
                 token = token.encode('ascii')
             token = base64.b64encode(token).decode('ascii')
             headers['Authorization'] = 'Basic ' + token
@@ -80,7 +80,7 @@ class BZAObject(dict):
 
         url = str(url)
 
-        if isinstance(data, text_type):
+        if isinstance(data, str):
             data = data.encode("utf-8")
 
         if isinstance(data, (dict, list)):
@@ -189,7 +189,7 @@ class User(BZAObject):
         return self
 
     def available_locations(self, include_harbors=False):
-        self.log.warn("Deprecated method used: available_locations")
+        self.log.warning("Deprecated method used: available_locations")
         if 'locations' not in self:
             self.fetch()
 
@@ -200,35 +200,6 @@ class User(BZAObject):
                 locations[loc_id] = loc
         return locations
 
-    def collection_draft(self, name, taurus_config, resource_files):
-        if resource_files:
-            draft_id = "taurus_%s" % id(self.token)
-            self._upload_collection_resources(resource_files, draft_id)
-            taurus_config.merge({"dataFiles": {"draftId": draft_id}})
-
-        collection_draft = self._import_config(taurus_config)
-        collection_draft['name'] = name
-        return collection_draft
-
-    def _import_config(self, config):
-        url = self.address + "/api/v4/multi-tests/taurus-import"
-        resp = self._request(url, data=config, method="POST")
-        return resp['result']
-
-    def _upload_collection_resources(self, resource_files, draft_id):
-        self.log.debug('Uploading resource files: %s', resource_files)
-        url = self.address + "/api/v4/web/elfinder/%s" % draft_id
-        body = MultiPartForm()
-        body.add_field("cmd", "upload")
-        body.add_field("target", "s1_Lw")
-        body.add_field('folder', 'drafts')
-
-        for rfile in resource_files:
-            body.add_file('upload[]', rfile)
-
-        hdr = {"Content-Type": str(body.get_content_type())}
-        self._request(url, body.form_as_bytes(), headers=hdr)
-
     def test_by_ids(self, account_id=None, workspace_id=None, project_id=None, test_id=None, test_type=None):
         account = self.accounts(ident=account_id).first()
         if not account:
@@ -242,11 +213,9 @@ class User(BZAObject):
         else:
             target = workspace
 
-        test = target.multi_tests(ident=test_id).first()
+        test = target.tests(ident=test_id, test_type=test_type).first()
         if not test:
-            test = target.tests(ident=test_id, test_type=test_type).first()
-            if not test:
-                raise ValueError("Test wasn't found")
+            raise ValueError("Test wasn't found")
 
         return account, workspace, project, test
 
@@ -345,28 +314,6 @@ class Workspace(BZAObject):
             tests.append(Test(self, item))
         return tests
 
-    def multi_tests(self, name=None, ident=None):
-        """
-        :rtype: BZAObjectsList[MultiTest]
-        """
-        params = OrderedDict({"workspaceId": self['id']})
-        if name is not None:
-            params["name"] = name
-        if ident is not None:
-            params["id"] = ident
-
-        res = self._request(self.address + '/api/v4/multi-tests?' + urlencode(params))
-        tests = BZAObjectsList()
-        for item in res['result']:
-            if ident is not None and item['id'] != ident:
-                continue
-
-            if name is not None and item['name'] != name:
-                continue
-
-            tests.append(MultiTest(self, item))
-        return tests
-
     def create_project(self, proj_name):
         params = {"name": str(proj_name), "workspaceId": self['id']}
         data = self._request(self.address + '/api/v4/projects', params)
@@ -408,28 +355,6 @@ class Project(BZAObject):
             tests.append(Test(self, item))
         return tests
 
-    def multi_tests(self, name=None, ident=None):
-        """
-        :rtype: BZAObjectsList[MultiTest]
-        """
-        params = OrderedDict({"projectId": self['id']})
-        if name is not None:
-            params["name"] = name
-        if ident is not None:
-            params["id"] = ident
-
-        res = self._request(self.address + '/api/v4/multi-tests?' + urlencode(params))
-        tests = BZAObjectsList()
-        for item in res['result']:
-            if ident is not None and item['id'] != ident:
-                continue
-
-            if name is not None and item['name'] != name:
-                continue
-
-            tests.append(MultiTest(self, item))
-        return tests
-
     def create_test(self, name, configuration):
         """
         :param name:
@@ -442,12 +367,6 @@ class Project(BZAObject):
         resp = self._request(url, data)
         return Test(self, resp['result'])
 
-    def create_multi_test(self, collection_draft):
-        collection_draft['projectId'] = self['id']
-        url = self.address + "/api/v4/multi-tests"
-        resp = self._request(url, data=collection_draft)
-        return MultiTest(self, resp['result'])
-
 
 class Test(BZAObject):
     def start_external(self):
@@ -470,24 +389,25 @@ class Test(BZAObject):
         return session, Master(self, result['master']), result['publicTokenUrl']
 
     def get_files(self):
-        path = self.address + "/api/v4/web/elfinder/%s" % self['id']
-        query = urlencode(OrderedDict({'cmd': 'open', 'target': 's1_Lw'}))
-        url = path + '?' + query
-        response = self._request(url)
-        return response["files"]
+        path = self.address + f"/api/v4/tests/{self['id']}/files"
+        response = self._request(path, method="GET")
+        return response["result"]
 
     def delete_files(self):
         files = self.get_files()
         self.log.debug("Test files: %s", [filedict['name'] for filedict in files])
         if not files:
             return
-        path = "/api/v4/web/elfinder/%s" % self['id']
-        query = "cmd=rm&" + "&".join("targets[]=%s" % fname['hash'] for fname in files)
-        url = self.address + path + '?' + query
-        response = self._request(url)
-        if len(response['removed']) == len(files):
-            self.log.debug("Successfully deleted %d test files", len(response['removed']))
-        return response['removed']
+        path = f"/api/v4/tests/{self['id']}/delete-file"
+        query = "&".join(f"fileName={fname['name']}" for fname in files)
+        url = self.address + path + "?" + query
+        response = self._request(url, method="POST")
+        removed = query.count('fileName')
+        if response['result']:
+            self.log.debug(f"Successfully deleted {removed} test files.")
+        else:
+            self.log.debug("Error while test files deletion.")
+        return removed
 
     def start(self, as_functional=False):
         url = self.address + "/api/v4/tests/%s/start" % self['id']
@@ -515,27 +435,28 @@ class Test(BZAObject):
         res = self._request(url, data=coll, method="PATCH")
         return res['result']
 
+    def started_passfail_validation(self):
+        # validate passfail configuration, get success if started
+        url = f"{self.address}/api/v4/tests/{self['id']}/validate"
+        resp = self._request(url, data={"files": [{"fileName": "taurus.yml"}], "performDataMerge": False})
+        result = resp.get('result')
+        if 'success' in result:
+            return result['success']
+        return False
 
-class MultiTest(BZAObject):
-    def start(self):
-        # NOTE: delayedStart=true means that BM will not start test until all instances are ready
-        # if omitted - instances will start once ready (not simultaneously),
-        # which may cause inconsistent data in aggregate report.
-        url = self.address + "/api/v4/multi-tests/%s/start?delayedStart=true" % self['id']
-        resp = self._request(url, method="POST")
-        return Master(self, resp['result'])
-
-    def stop(self):
-        url = self.address + "/api/v4/multi-tests/%s/stop" % self['id']
-        self._request(url, method='POST')
-
-    def update_collection(self, coll):
-        url = self.address + "/api/v4/multi-tests/%s" % self['id']
-        self._request(url, data=coll, method="PATCH")
-
-    def delete(self):
-        url = self.address + "/api/v4/multi-tests/%s" % self['id']
-        self._request(url, method="DELETE")
+    def get_passfail_validation(self):
+        # get passfail validation status and results, log warnings if present
+        url = f"{self.address}/api/v4/tests/{self['id']}/validations"
+        resp = self._request(url, method='GET')
+        validated = False
+        for result in resp.get('result'):
+            if result['status'] == 100:
+                for warning_msg in result['warnings'] + result['fileWarnings']:
+                    self.log.warning(f"Passfail Warning: {warning_msg}")
+                validated = True
+        if not validated:
+            self.log.error(f"Passfail error: Unable to validate by {url}.")
+        return validated
 
 
 class Master(BZAObject):
