@@ -26,18 +26,18 @@ import traceback
 from logging import Formatter
 from optparse import OptionParser, Option
 from tempfile import NamedTemporaryFile
+from urllib.error import HTTPError
 
 import yaml
 from colorlog import ColoredFormatter
 
-import bzt
-
 from bzt import ManualShutdown, NormalShutdown, RCProvider, TaurusException, AutomatedShutdown
 from bzt import TaurusInternalException, TaurusConfigError, TaurusNetworkError, ToolError
+
 from bzt.engine import Engine, Configuration, SETTINGS, EXEC
 from bzt.linter import ConfigurationLinter
-from bzt.six import HTTPError, string_types, get_stacktrace, integer_types
-from bzt.utils import is_int, BetterDict, is_url, RESOURCES_DIR
+from bzt.utils import get_stacktrace, is_int, BetterDict, is_url, RESOURCES_DIR
+from bzt.resources.version import VERSION, GIT_INFO, BUILD
 
 
 class CLI(object):
@@ -55,10 +55,23 @@ class CLI(object):
         self.options = options
         self.setup_logging(options)
         self.log = logging.getLogger('')
-        self.log.info("Taurus CLI Tool v%s", bzt.VERSION)
+        self.log.info("Taurus CLI Tool v%s", VERSION)
+        self.log.debug("Build: %s", BUILD)
+        self.log.debug("Extended git info: %s", GIT_INFO)
         self.log.debug("Command-line options: %s", self.options)
         self.log.debug("Python: %s %s", platform.python_implementation(), platform.python_version())
         self.log.debug("OS: %s", platform.uname())
+
+        try:
+            self.log.debug("Path to interpreter: {}".format(sys.executable))
+            self.log.debug("Path to packages: {}".format(sys.path))
+            self.log.debug("Default python: {}".format(shutil.which('python' or 'not found')))
+            self.log.debug("Default python3: {}".format(shutil.which('python3' or 'not found')))
+
+        except BaseException as exc:
+            self.log.warning("Extended python info getting error: {}".format(exc))
+
+
         self.engine = Engine(self.log)
         self.exit_code = 0
 
@@ -75,7 +88,7 @@ class CLI(object):
             'CRITICAL': 'bold_red',
         }
         fmt_file = Formatter("[%(asctime)s %(levelname)s %(name)s] %(message)s")
-        if sys.stdout.isatty():
+        if sys.stdout and sys.stdout.isatty():
             fmt_verbose = ColoredFormatter("%(log_color)s[%(asctime)s %(levelname)s %(name)s] %(message)s",
                                            log_colors=colors)
             fmt_regular = ColoredFormatter("%(log_color)s%(asctime)s %(levelname)s: %(message)s",
@@ -182,6 +195,7 @@ class CLI(object):
             CLI.console_handler.setLevel(logging.DEBUG)
         self.engine.create_artifacts_dir(configs, merged_config)
         self.engine.default_cwd = os.getcwd()
+        self.engine.set_pythonpath()
         self.engine.eval_env()  # yacky, I don't like having it here, but how to apply it after aliases and artif dir?
 
     def __is_verbose(self):
@@ -267,6 +281,14 @@ class CLI(object):
             except BaseException as exc:
                 self.handle_exception(exc)
 
+        if self.options.verbose:
+            for module_name in sys.modules:
+                version = str(getattr(sys.modules[module_name], '__version__', ""))
+                file = getattr(sys.modules[module_name], '__file__', "")
+                if version:
+                    module_name = "-".join((module_name, version))
+                    self.log.debug("\t{}\t{}".format(module_name, file))
+
         self.log.info("Artifacts dir: %s", self.engine.artifacts_dir)
         if self.engine.artifacts_dir is None:
             self.log.info("Log file: %s", self.options.log)
@@ -493,8 +515,10 @@ class ConfigOverrider(object):
         if isinstance(obj, dict):            
             for k, v in obj.items():
                 obj[k] = self.__apply_mult_override(v, key, replace_value)
-        if key in obj:
+        if isinstance(obj, dict) and key in obj:
             obj[key] = replace_value
+        if isinstance(obj, list) and key in obj:
+            obj[obj.index(key)] = replace_value
         return obj
 
     def __apply_single_override(self, dest, name, value):
@@ -509,25 +533,25 @@ class ConfigOverrider(object):
         for index, part in enumerate(parts[:-1]):
             self.__ensure_list_capacity(pointer, part, parts[index + 1])
 
-            if isinstance(part, integer_types):
+            if isinstance(part, int):
                 if part < 0:
-                    if isinstance(parts[index + 1], integer_types):
+                    if isinstance(parts[index + 1], int):
                         pointer.append([])
                     else:
                         pointer.append(BetterDict())
                     pointer = pointer[-1]
                 else:
                     pointer = pointer[part]
-            elif isinstance(parts[index + 1], integer_types) and isinstance(pointer, dict):
+            elif isinstance(parts[index + 1], int) and isinstance(pointer, dict):
                 pointer = pointer.get(part, [], force_set=True)
             else:
                 pointer = pointer.get(part, force_set=True)
         self.__ensure_list_capacity(pointer, parts[-1])
         self.log.debug("Applying: [%s]=%s", parts[-1], value)
-        if isinstance(parts[-1], string_types) and parts[-1][0] == '*':
+        if isinstance(parts[-1], str) and parts[-1][0] == '*':
             return self.__apply_mult_override(pointer, parts[-1][1:], value)
 
-        if isinstance(parts[-1], string_types) and parts[-1][0] == '^':
+        if isinstance(parts[-1], str) and parts[-1][0] == '^':
             item = parts[-1][1:]
 
             if isinstance(pointer, list):
@@ -567,10 +591,10 @@ class ConfigOverrider(object):
         :type pointer: list
         :type part: int
         """
-        if isinstance(pointer, list) and isinstance(part, integer_types):
+        if isinstance(pointer, list) and isinstance(part, int):
             while len(pointer) <= part:
                 self.log.debug("Len %s less than %s", len(pointer), part)
-                if isinstance(next_part, integer_types):
+                if isinstance(next_part, int):
                     pointer.append([])
                 else:
                     pointer.append(BetterDict())
@@ -613,7 +637,7 @@ class OptionParserWithAliases(OptionParser, object):
 
 def get_option_parser():
     usage = "Usage: bzt [options] [configs] [-aliases]"
-    dsc = "BlazeMeter Taurus Tool v%s, the configuration-driven test running engine" % bzt.VERSION
+    dsc = "BlazeMeter Taurus Tool v%s, the configuration-driven test running engine" % VERSION
     parser = OptionParserWithAliases(usage=usage, description=dsc, prog="bzt")
     parser.add_option('-l', '--log', action='store', default=None,
                       help="Log file location")
