@@ -22,7 +22,6 @@ import json
 import logging
 import os
 import pkgutil
-import re
 import shutil
 import sys
 import threading
@@ -30,16 +29,18 @@ import time
 import traceback
 import uuid
 from distutils.version import LooseVersion
+from urllib import parse
 
-import bzt
 from bzt import ManualShutdown, get_configs_dir, TaurusConfigError, TaurusInternalException
-from bzt.six import string_types, text_type, parse, reraise
-from bzt.utils import load_class, BetterDict, ensure_is_dict, dehumanize_time, is_windows, is_linux
+from bzt.utils import reraise, load_class, BetterDict, ensure_is_dict, dehumanize_time, is_windows, is_linux
 from bzt.utils import shell_exec, get_full_path, ExceptionalDownloader, get_uniq_name, HTTPClient, Environment
 from .dicts import Configuration
 from .modules import Provisioning, Reporter, Service, Aggregator, EngineModule
 from .names import EXEC, TAURUS_ARTIFACTS_DIR, SETTINGS
 from .templates import Singletone
+from ..environment_helpers import expand_variable_with_os, custom_expandvars, expand_envs_with_os
+
+from bzt.resources.version import VERSION
 
 
 class Engine(object):
@@ -86,8 +87,29 @@ class Engine(object):
         self.logging_level_down = lambda: None
         self.logging_level_up = lambda: None
 
+        self.user_pythonpath = None
+        self.temp_pythonpath = None
+
         self._http_client = None
 
+    def set_pythonpath(self):
+        version = sys.version.split(' ')[0]
+        path_suffix = os.path.join('python-packages', version)
+        self.user_pythonpath = get_full_path(os.path.join("~", ".bzt", path_suffix))
+        self.temp_pythonpath = get_full_path(os.path.join(self.artifacts_dir, path_suffix))
+        current_pythonpath = os.environ.get('PYTHONPATH', '')
+        paths = self.user_pythonpath, self.temp_pythonpath, current_pythonpath
+
+        self.log.debug("Set PYTHONPATH to :\n\tUSER: '{}' +\n\tTEMP: '{}' +\n\tCURRENT: '{}'".format(*paths))
+        try:
+            user_packages = os.listdir(self.user_pythonpath)
+        except:
+            user_packages = []
+
+        self.log.debug("Content of user packages dir: {}".format(user_packages))
+
+        os.environ['PYTHONPATH'] = os.pathsep.join(paths)
+
     def configure(self, user_configs, read_config_files=True):
         """
         Load configuration files
@@ -109,7 +131,7 @@ class Engine(object):
             self.config.load(included_configs)
         self.config['included-configs'] = all_includes
 
-        self.config.merge({"version": bzt.VERSION})
+        self.config.merge({"version": VERSION})
         self.get_http_client()
 
         if self.config.get(SETTINGS).get("check-updates", True):
@@ -391,7 +413,7 @@ class Engine(object):
             artifacts_dir = self.config.get(SETTINGS, force_set=True).get("artifacts-dir", self.ARTIFACTS_DIR)
             self.artifacts_dir = datetime.datetime.now().strftime(artifacts_dir)
 
-        self.artifacts_dir = get_full_path(self.artifacts_dir)
+        self.artifacts_dir = self.__expand_artifacts_dir()
 
         self.log.info("Artifacts dir: %s", self.artifacts_dir)
         os.environ[TAURUS_ARTIFACTS_DIR] = self.artifacts_dir
@@ -411,6 +433,13 @@ class Engine(object):
         for artifact in existing_artifacts:
             self.existing_artifact(artifact)
 
+    def __expand_artifacts_dir(self):
+        envs = self.__get_envs_from_config()
+        artifacts_dir = custom_expandvars(self.artifacts_dir, envs)
+        artifacts_dir = expand_variable_with_os(artifacts_dir)
+        artifacts_dir = get_full_path(artifacts_dir)
+        return artifacts_dir
+
     def is_functional_mode(self):
         return self.aggregator is not None and self.aggregator.is_functional
 
@@ -678,7 +707,7 @@ class Engine(object):
 
     def _check_updates(self, install_id):
         try:
-            params = (bzt.VERSION, install_id)
+            params = (VERSION, install_id)
             addr = "https://gettaurus.org/updates/?version=%s&installID=%s" % params
             self.log.debug("Requesting updates info: %s", addr)
             client = self.get_http_client()
@@ -686,9 +715,9 @@ class Engine(object):
 
             data = response.json()
             self.log.debug("Taurus updates info: %s", data)
-            mine = LooseVersion(bzt.VERSION)
+            mine = LooseVersion(VERSION)
             latest = LooseVersion(data['latest'])
-            if mine < latest or data['needsUpgrade']:
+            if mine != "DEV" and (mine < latest or data['needsUpgrade']):
                 msg = "There is newer version of Taurus %s available, consider upgrading. " \
                       "What's new: http://gettaurus.org/docs/Changelog/"
                 self.log.warning(msg, latest)
@@ -703,35 +732,38 @@ class Engine(object):
         """
         Should be done after `configure`
         """
-        envs = self.config.get(SETTINGS, force_set=True).get("env", force_set=True)
-        envs[TAURUS_ARTIFACTS_DIR] = self.artifacts_dir
-
-        for varname in envs:
-            if envs[varname]:
-                envs[varname] = str(envs[varname])
-                envs[varname] = os.path.expandvars(envs[varname])
-
-        for varname in envs:
-            if envs[varname] is None:
-                if varname in os.environ:
-                    os.environ.pop(varname)
-            else:
-                os.environ[varname] = str(envs[varname])
-
-        def custom_expandvars(value):
-            parts = re.split(r'(\$\{.*?\})', value)
-            value = ''
-            for item in parts:
-                if item and item.startswith("${") and item.endswith("}"):
-                    key = item[2:-1]
-                    if key in envs:
-                        item = envs[key]
-                if item is not None:
-                    value += text_type(item)
-            return value
+        envs = self.__get_envs_from_config()
+        envs = expand_envs_with_os(envs)
 
         def apply_env(value, key, container):
-            if isinstance(value, string_types):
-                container[key] = custom_expandvars(value)
+            if isinstance(value, str):
+                container[key] = custom_expandvars(value, envs)
 
         BetterDict.traverse(self.config, apply_env)
+
+        self.__export_variables_to_os()
+
+    def __export_variables_to_os(self):
+        """
+        Export all user-defined environment variables to the system.
+        Example:
+
+        settings:
+          env:
+            FOO: bbb/ccc
+            BAR: aaa
+        """
+        envs = self.__get_envs_from_config()
+
+        for var_name in envs:
+            if envs[var_name] is None:
+                if var_name in os.environ:
+                    os.environ.pop(var_name)
+            else:
+                os.environ[var_name] = envs[var_name]
+                self.log.debug("OS env: %s=%s", var_name, envs[var_name])
+
+    def __get_envs_from_config(self):
+        envs = self.config.get(SETTINGS, force_set=True).get("env", force_set=True)
+        envs[TAURUS_ARTIFACTS_DIR] = self.artifacts_dir
+        return envs
