@@ -18,6 +18,7 @@ limitations under the License.
 import os
 import re
 from distutils.version import LooseVersion
+from lxml import etree
 
 from bzt import TaurusInternalException, TaurusConfigError
 from bzt.engine import Scenario
@@ -25,7 +26,7 @@ from bzt.jmx import JMX
 from bzt.jmx.base import cond_int
 from bzt.jmx.threadgroups import ThreadGroup, ConcurrencyThreadGroup, ThreadGroupHandler
 from bzt.requests_model import RequestVisitor, has_variable_pattern, HierarchicRequestParser
-from bzt.six import etree, iteritems, numeric_types, string_types
+from bzt.utils import iteritems, numeric_types
 from bzt.utils import BetterDict, dehumanize_time, ensure_is_dict, load_class, guess_delimiter
 
 
@@ -34,6 +35,9 @@ class RequestCompiler(RequestVisitor):
         super(RequestCompiler, self).__init__()
         self.jmx_builder = jmx_builder
 
+    def visit_mqttrequest(self, request):
+        return self.jmx_builder.compile_request(request)
+
     def visit_hierarchichttprequest(self, request):
         return self.jmx_builder.compile_request(request)
 
@@ -117,7 +121,7 @@ class LoadSettingsProcessor(object):
         groups = list(self.tg_handler.groups(jmx))
 
         # user concurrency is jmeter variable, write it to tg as is
-        if isinstance(self.load.concurrency, string_types):
+        if isinstance(self.load.concurrency, str):
             target_list = [(group, self.load.concurrency) for group in groups]
         else:  # concurrency is numeric or empty
             raw = self.load.concurrency is None  # keep existed concurrency if self.load.concurrency is omitted
@@ -206,9 +210,10 @@ class LoadSettingsProcessor(object):
 
 class ProtocolHandler(object):
 
-    def __init__(self, sys_props):
+    def __init__(self, sys_props, engine):
         super(ProtocolHandler, self).__init__()
         self.system_props = sys_props
+        self.engine = engine
 
     def get_toplevel_elements(self, scenario):
         return []
@@ -248,7 +253,7 @@ class JMeterScenarioBuilder(JMX):
         self.protocol_handlers = {}
         for protocol, cls_name in iteritems(self.executor.settings.get("protocol-handlers")):
             cls_obj = load_class(cls_name)
-            instance = cls_obj(self.system_props)
+            instance = cls_obj(self.system_props, self.engine)
             self.protocol_handlers[protocol] = instance
         self.FIELD_KEYSTORE_CONFIG = 'keystore-config'
 
@@ -399,12 +404,17 @@ class JMeterScenarioBuilder(JMX):
             children.append(etree.Element("hashTree"))
 
     @staticmethod
-    def __add_jsr_elements(children, req):
+    def __add_jsr_elements(children, req, get_from_config=True):
         """
         :type children: etree.Element
         :type req: Request
         """
-        jsrs = req.config.get("jsr223", [])
+        jsrs = []
+        if get_from_config:
+            jsrs = req.config.get("jsr223", [])
+        else:
+            jsrs = req.get("jsr223", [])
+
         if not isinstance(jsrs, list):
             jsrs = [jsrs]
         for idx, _ in enumerate(jsrs):
@@ -423,7 +433,9 @@ class JMeterScenarioBuilder(JMX):
             children.append(etree.Element("hashTree"))
 
     def __gen_requests(self, scenario):
-        requests = scenario.get_requests(parser=HierarchicRequestParser)
+        http_protocol = scenario.data.get('protocol', 'http') == 'http'
+        requests = scenario.get_requests(parser=HierarchicRequestParser, require_url=http_protocol)
+
         elements = []
         for compiled in self.compile_requests(requests):
             elements.extend(compiled)
@@ -437,6 +449,7 @@ class JMeterScenarioBuilder(JMX):
         elements.extend(self.__gen_keystore_config(scenario))
         elements.extend(self.__gen_data_sources(scenario))
         elements.extend(self.__gen_requests(scenario))
+        self.__add_jsr_elements(elements, scenario, False)
         return elements
 
     def compile_request(self, request):
