@@ -32,7 +32,6 @@ from bzt import TaurusInternalException
 from bzt.cli import CLI
 from bzt.engine import Configuration, EXEC
 from bzt.jmx import JMX
-from bzt.six import string_types
 from bzt.utils import get_full_path
 from bzt.requests_model import has_variable_pattern
 
@@ -1290,7 +1289,7 @@ class JMXasDict(JMX):
     def _get_content_type(headers):
         for header in headers:
             if header.lower() == 'content-type':
-                if isinstance(headers[header], string_types):
+                if isinstance(headers[header], str):
                     return headers[header].lower()
                 else:
                     return headers[header]
@@ -1318,7 +1317,7 @@ class JMXasDict(JMX):
                 scenario_json = self._get_content_type(tg_scenario_settings['headers']) == 'application/json'
 
             for request in requests:
-                if not ('body' in request and isinstance(request['body'], string_types)):
+                if not ('body' in request and isinstance(request['body'], str)):
                     continue
                 request_content_header = 'headers' in request and self._get_content_type(request['headers'])
 
