@@ -30,8 +30,7 @@ from yaml.representer import SafeRepresenter
 
 from bzt import TaurusInternalException, TaurusConfigError
 from bzt.engine import Aggregator
-from bzt.six import iteritems, PY3, text_type
-from bzt.utils import dehumanize_time, JSONConvertible
+from bzt.utils import iteritems, dehumanize_time, JSONConvertible
 
 log = logging.getLogger('aggregator')
 
@@ -333,20 +332,6 @@ class KPISet(dict):
         for item in super(KPISet, self).items():
             yield (item[0], self.__getitem__(item[0]))
 
-    def iteritems(self):
-        if PY3:
-            raise TaurusInternalException("Invalid call")
-
-        for item in super(KPISet, self).iteritems():
-            yield (item[0], self.__getitem__(item[0]))
-
-    def viewitems(self):
-        if PY3:
-            raise TaurusInternalException("Invalid call")
-
-        for item in super(KPISet, self).viewitems():
-            yield (item[0], self.__getitem__(item[0]))
-
     def viewvalues(self):
         raise TaurusInternalException("Invalid call")
 
@@ -541,7 +526,7 @@ class ResultsProvider(object):
         if not key or limit <= 0:
             return key
 
-        if not isinstance(key, text_type):
+        if not isinstance(key, str):
             key = key.decode('utf-8')
 
         if key.lower() in dataset.exact_set:
@@ -594,9 +579,10 @@ class ResultsProvider(object):
         """
         for datapoint in self._calculate_datapoints(final_pass):
             current = datapoint[DataPoint.CURRENT]
-            self.__merge_to_cumulative(current)
-            datapoint[DataPoint.CUMULATIVE] = copy.deepcopy(self.cumulative)  # FIXME: this line eats RAM like hell!
-            datapoint.recalculate()
+            if datapoint[DataPoint.CUMULATIVE] or not self._ramp_up_exclude():
+                self.__merge_to_cumulative(current)
+                datapoint[DataPoint.CUMULATIVE] = copy.deepcopy(self.cumulative)  # FIXME: this line eats RAM like hell!
+                datapoint.recalculate()
 
             for listener in self.listeners:
                 listener.aggregated_second(datapoint)
@@ -609,6 +595,13 @@ class ResultsProvider(object):
         """
         yield
 
+    @abstractmethod
+    def _ramp_up_exclude(self):
+        """
+        :rtype : bool
+        """
+        return False
+
 
 class ResultsReader(ResultsProvider):
     """
@@ -766,6 +759,7 @@ class ConsolidatingAggregator(Aggregator, ResultsProvider):
         self.buffer = {}
         self.histogram_max = 5.0
         self._sticky_concurrencies = {}
+        self.min_timestamp = None
 
     def prepare(self):
         """
@@ -859,7 +853,6 @@ class ConsolidatingAggregator(Aggregator, ResultsProvider):
                 for point in underling.datapoints(final_pass):
                     had_data = True
                     self._put_into_buffer(point)
-                    break
 
             if not had_data:
                 break
@@ -874,6 +867,16 @@ class ConsolidatingAggregator(Aggregator, ResultsProvider):
                 tstamp = mints
         self.buffer.setdefault(tstamp, []).append(point)
 
+    def _get_max_ramp_up(self):
+        ramp_ups = [0]
+        for execution in self.engine.config['execution']:
+            if 'ramp-up' in execution:
+                ramp_ups.append(dehumanize_time(execution['ramp-up']))
+        return max(ramp_ups)
+
+    def _ramp_up_exclude(self):
+        return self.engine.config.get('settings').get('ramp-up-exclude')
+
     def _calculate_datapoints(self, final_pass=False):
         """
         Override ResultsProvider._calculate_datapoints
@@ -891,6 +894,13 @@ class ConsolidatingAggregator(Aggregator, ResultsProvider):
             points_to_consolidate = self.buffer.pop(tstamp)
 
             for subresult in points_to_consolidate:
+                if self._ramp_up_exclude():
+                    if not self.min_timestamp:
+                        self.min_timestamp = subresult['ts']
+
+                    if subresult['ts'] < self.min_timestamp + self._get_max_ramp_up():
+                        subresult[DataPoint.CUMULATIVE] = dict()
+
                 if not subresult[DataPoint.SOURCE_ID]:
                     raise ValueError("Reader must provide source ID for datapoint")
                 self._sticky_concurrencies[subresult[DataPoint.SOURCE_ID]] = {
