@@ -24,9 +24,10 @@ from abc import abstractmethod
 from collections import deque
 from datetime import datetime
 from itertools import groupby, islice, chain
+from io import StringIO
 
 from bzt import TaurusInternalException
-from bzt.six import StringIO, numeric_types
+from bzt.utils import numeric_types
 from logging import StreamHandler
 from urwid import LineBox, ListBox, RIGHT, CENTER, BOTTOM, CLIP, GIVEN, ProgressBar
 from urwid import Text, Pile, WEIGHT, Filler, Columns, Widget, CanvasCombine
@@ -36,11 +37,11 @@ from urwid.graphics import BigText
 from urwid.listbox import SimpleListWalker
 from urwid.widget import Divider
 
-import bzt
 from bzt.engine import Reporter, Singletone
 from bzt.modules.aggregator import DataPoint, KPISet, AggregatorListener, ResultsProvider
 from bzt.modules.provisioning import Local
 from bzt.utils import humanize_time, is_windows, DummyScreen
+from bzt.resources.version import VERSION
 
 try:
     from bzt.modules.screen import GUIScreen
@@ -91,7 +92,7 @@ class ConsoleStatusReporter(Reporter, AggregatorListener, Singletone):
             self.log.info("Invalid screen type %r, trying 'console'", screen_type)
             screen_type = "console"
 
-        if not sys.stdout.isatty():
+        if not (sys.stdout and sys.stdout.isatty()):
             self.log.debug("Not in terminal, using dummy screen")
             screen_type = "dummy"
 
@@ -116,7 +117,7 @@ class ConsoleStatusReporter(Reporter, AggregatorListener, Singletone):
 
         disable = self.settings.get('disable', 'auto')
         explicit_disable = isinstance(disable, (bool, int)) and disable
-        auto_disable = str(disable).lower() == 'auto' and not sys.stdout.isatty()
+        auto_disable = str(disable).lower() == 'auto' and not (sys.stdout and sys.stdout.isatty())
         if explicit_disable or auto_disable or self.engine.is_functional_mode():
             self.disabled = True
             return
@@ -161,11 +162,12 @@ class ConsoleStatusReporter(Reporter, AggregatorListener, Singletone):
         line = "Current: %s vu\t%s succ\t%s fail\t%.3f avg rt"
         stats = (cur[KPISet.CONCURRENCY], cur[KPISet.SUCCESSES], cur[KPISet.FAILURES],
                  cur[KPISet.AVG_RESP_TIME])
-        cumul = self._last_datapoint[DataPoint.CUMULATIVE]['']
-        line += "\t/\t"  # separator
-        line += "Cumulative: %.3f avg rt, %d%% failures"
-        stats += (cumul[KPISet.AVG_RESP_TIME], 100 * (cumul[KPISet.FAILURES] / cumul[KPISet.SAMPLE_COUNT]))
-        log_method(line % stats)
+        if '' in self._last_datapoint[DataPoint.CUMULATIVE]:
+            cumul = self._last_datapoint[DataPoint.CUMULATIVE]['']
+            line += "\t/\t"  # separator
+            line += "Cumulative: %.3f avg rt, %d%% failures"
+            stats += (cumul[KPISet.AVG_RESP_TIME], 100 * (cumul[KPISet.FAILURES] / cumul[KPISet.SAMPLE_COUNT]))
+            log_method(line % stats)
 
     def __start_screen(self):
         """
@@ -257,7 +259,7 @@ class ConsoleStatusReporter(Reporter, AggregatorListener, Singletone):
         if isinstance(self.screen, DummyScreen):
             return
 
-        if sys.stdout.isatty():
+        if sys.stdout and sys.stdout.isatty():
             if not is_windows():
                 self.__detect_console_logger()
 
@@ -1010,15 +1012,18 @@ class DetailedErrorString(ListBox):
 
         self.body.append(Text(("stat-hdr", " Errors: ")))
         overall = data.get(self.key)
-        errors = overall.get('').get(KPISet.ERRORS)
-        if errors:
-            err_template = "{0} of: {1}"
-            for error in sorted(errors, key=lambda _err: _err.get('cnt'), reverse=True):
-                err_description = error.get('msg')
-                err_count = error.get('cnt')
+        if '' in overall:
+            errors = overall.get('').get(KPISet.ERRORS)
+            if errors:
+                err_template = "{0} of: {1}"
+                for error in sorted(errors, key=lambda _err: _err.get('cnt'), reverse=True):
+                    err_description = error.get('msg')
+                    err_count = error.get('cnt')
 
-                self.body.append(
-                    Text(("stat-txt", err_template.format(err_count, err_description)), wrap=CLIP))
+                    self.body.append(
+                        Text(("stat-txt", err_template.format(err_count, err_description)), wrap=CLIP))
+            else:
+                self.body.append(Text(("stat-txt", "No failures occured")))
         else:
             self.body.append(Text(("stat-txt", "No failures occured")))
 
@@ -1102,7 +1107,7 @@ class TaurusLogo(Pile):
         """
         Update rotating sticks
         """
-        txt = self.by_text % (self.seq[self.idx], bzt.VERSION, self.seq[self.idx])
+        txt = self.by_text % (self.seq[self.idx], VERSION, self.seq[self.idx])
         # noinspection PyPropertyAccess
         self.byb.body.set_text(txt)
         self.idx += 1
