@@ -28,8 +28,10 @@ import traceback
 from collections import Counter, namedtuple
 from distutils.version import LooseVersion
 from itertools import dropwhile
+from io import StringIO
 
 from cssselect import GenericTranslator
+from lxml import etree
 
 from bzt import TaurusConfigError, ToolError, TaurusInternalException, TaurusNetworkError
 from bzt.engine import Scenario, FileLister, HavingInstallableTools, ScenarioExecutor
@@ -39,7 +41,7 @@ from bzt.modules.aggregator import ResultsReader, DataPoint, KPISet
 from bzt.modules.console import WidgetProvider, ExecutorWidget
 from bzt.modules.functional import FunctionalResultsReader, FunctionalSample
 from bzt.requests_model import ResourceFilesCollector, has_variable_pattern, HierarchicRequestParser
-from bzt.six import iteritems, string_types, StringIO, etree, numeric_types, PY2, unicode_decode
+from bzt.utils import iteritems, numeric_types, unicode_decode
 from bzt.utils import get_full_path, EXE_SUFFIX, MirrorsManager, ExceptionalDownloader, get_uniq_name, is_windows
 from bzt.utils import BetterDict, guess_csv_dialect, dehumanize_time, CALL_PROBLEMS
 from bzt.utils import unzip, RequiredTool, JavaVM, shutdown_process, ProgressBarContext, TclLibrary, FileReader
@@ -191,7 +193,7 @@ class JMeterExecutor(ScenarioExecutor, WidgetProvider, FileLister, HavingInstall
         selector = 'jmeterTestPlan'
         test_plan = jmx.get(selector)[0]
         ver = test_plan.get('jmeter')
-        if isinstance(ver, string_types):
+        if isinstance(ver, str):
             index = ver.find(" ")
             if index != -1:
                 return ver[:index]
@@ -1144,9 +1146,6 @@ class IncrementalCSVReader(object):
                 self.log.debug("Analyzed header line: %s", self.csv_reader.fieldnames)
                 continue
 
-            if PY2:  # todo: fix csv parsing of unicode strings on PY2
-                line = line.encode('utf-8')
-
             self.buffer.write(line)
 
         if lines_read:
@@ -1354,9 +1353,9 @@ class JMeter(RequiredTool):
     JMeter tool
     """
     PLUGINS_MANAGER_VERSION = "1.3"
-    PLUGINS_MANAGER = 'https://search.maven.org/remotecontent?filepath=kg/apc/jmeter-plugins-manager/' \
-                      '{ver}/jmeter-plugins-manager-{ver}.jar'.format(ver=PLUGINS_MANAGER_VERSION)
-    CMDRUNNER = 'https://search.maven.org/remotecontent?filepath=kg/apc/cmdrunner/2.2/cmdrunner-2.2.jar'
+    PLUGINS_MANAGER = 'https://search.maven.org/remotecontent?filepath=kg/apc/jmeter-plugins-manager/{version}/jmeter-plugins-manager-{version}.jar'
+    COMMAND_RUNNER_VERSION = "2.2"
+    COMMAND_RUNNER = 'https://search.maven.org/remotecontent?filepath=kg/apc/cmdrunner/{version}/cmdrunner-{version}.jar'
     VERSION = "5.2.1"
 
     def __init__(self, config=None, props=None, **kwargs):
@@ -1371,6 +1370,14 @@ class JMeter(RequiredTool):
         if download_link is not None:
             download_link = download_link.format(version=version)
 
+        plugins_manager_settings = settings.get("plugins-manager", {})
+        plugins_manager_version = plugins_manager_settings.get("version", JMeter.PLUGINS_MANAGER_VERSION)
+        self.plugins_manager = plugins_manager_settings.get("download-link", JMeter.PLUGINS_MANAGER).format(version=plugins_manager_version)
+
+        command_runner_settings = settings.get("command-runner", {})
+        command_runner_version = command_runner_settings.get("version", JMeter.COMMAND_RUNNER_VERSION)
+        self.command_runner = command_runner_settings.get("download-link", JMeter.COMMAND_RUNNER).format(version=command_runner_version)
+
         self.plugins = settings.get("plugins", [])
 
         super(JMeter, self).__init__(tool_path=jmeter_path, download_link=download_link, version=version, **kwargs)
@@ -1521,13 +1528,13 @@ class JMeter(RequiredTool):
     def install(self):
         dest = get_full_path(self.tool_path, step_up=2)
         self.log.info("Will install %s into %s", self.tool_name, dest)
-        plugins_manager_name = os.path.basename(self.PLUGINS_MANAGER)
-        cmdrunner_name = os.path.basename(self.CMDRUNNER)
+        plugins_manager_name = os.path.basename(self.plugins_manager)
+        command_runner_name = os.path.basename(self.command_runner)
         plugins_manager_path = os.path.join(dest, 'lib', 'ext', plugins_manager_name)
-        cmdrunner_path = os.path.join(dest, 'lib', cmdrunner_name)
+        command_runner_path = os.path.join(dest, 'lib', command_runner_name)
         direct_install_tools = [  # source link and destination
-            [self.PLUGINS_MANAGER, plugins_manager_path],
-            [self.CMDRUNNER, cmdrunner_path]]
+            [self.plugins_manager, plugins_manager_path],
+            [self.command_runner, command_runner_path]]
         plugins_manager_cmd = self._pmgr_path()
 
         self.__install_jmeter(dest)
