@@ -9,14 +9,14 @@ from collections import OrderedDict, namedtuple
 
 import csv
 import psutil
+from urllib.parse import urlencode
 from urwid import Pile, Text
 
 from bzt import TaurusNetworkError, TaurusInternalException, TaurusConfigError
 from bzt.engine import Service, Singletone
 from bzt.modules.console import WidgetProvider, PrioritizedWidget
 from bzt.modules.passfail import FailCriterion
-from bzt.six import iteritems, urlencode, b, stream_decode, integer_types, PY3
-from bzt.utils import dehumanize_time, BetterDict
+from bzt.utils import iteritems, b, stream_decode, dehumanize_time, BetterDict
 
 
 class Monitoring(Service, WidgetProvider, Singletone):
@@ -188,14 +188,11 @@ class LocalClient(MonitoringClient):
         self.interval = dehumanize_time(self.config.get("interval", self.engine.check_interval))
 
         if self.config.get("logging", False):
-            if not PY3:
-                self.log.warning("Logging option doesn't work on python2.")
-            else:
-                self.logs_file = self.engine.create_artifact("local_monitoring_logs", ".csv")
-                with open(self.logs_file, "a", newline='') as mon_logs:
-                    logs_writer = csv.writer(mon_logs, delimiter=',')
-                    metrics = ['ts'] + sorted([metric for metric in good_list])
-                    logs_writer.writerow(metrics)
+            self.logs_file = self.engine.create_artifact("local_monitoring_logs", ".csv")
+            with open(self.logs_file, "a", newline='') as mon_logs:
+                logs_writer = csv.writer(mon_logs, delimiter=',')
+                metrics = ['ts'] + sorted([metric for metric in good_list])
+                logs_writer.writerow(metrics)
 
     def get_data(self):
         now = time.time()
@@ -205,7 +202,7 @@ class LocalClient(MonitoringClient):
             self._cached_data = []
             metric_values = self._get_resource_stats()
 
-            if self.logs_file and PY3:
+            if self.logs_file:
                 with open(self.logs_file, "a", newline='') as mon_logs:
                     line = [str(round(now))] + [str(metric_values[x]) for x in sorted(metric_values.keys())]
                     logs_writer = csv.writer(mon_logs, delimiter=',')
@@ -235,7 +232,7 @@ class LocalMonitor(object):
     def resource_stats(self):
         if not self._last_check:
             self._disk_counters = self.__get_disk_counters()
-            self._net_counters = psutil.net_io_counters()
+            self._net_counters = self.__get_net_counters()
             self._last_check = time.time()
             time.sleep(0.2)  # small enough for human, big enough for machine
 
@@ -244,15 +241,6 @@ class LocalMonitor(object):
         self._last_check = now
         return self._calc_resource_stats(interval)
 
-    def __get_mem_info(self):
-        try:
-            return psutil.virtual_memory().percent
-        except KeyError:
-            if not self._informed_on_mem_issue:
-                self.log.debug("Failed to get memory usage: %s", traceback.format_exc())
-                self.log.warning("Failed to get memory usage, use -v to get more detailed error info")
-                self._informed_on_mem_issue = True
-
     def _calc_resource_stats(self, interval):
         """
         Get local resource stats
@@ -265,7 +253,7 @@ class LocalMonitor(object):
             result['mem'] = self.__get_mem_info()
 
         if 'disk-space' in self.metrics:
-            result['disk-space'] = psutil.disk_usage(self.engine.artifacts_dir).percent
+            result['disk-space'] = self.__get_disk_usage(self.engine.artifacts_dir).percent
 
         if 'engine-loop' in self.metrics:
             result['engine-loop'] = self.engine.engine_loop_utilization
@@ -282,10 +270,10 @@ class LocalMonitor(object):
                 result['conn-all'] = 0
 
         if 'cpu' in self.metrics:
-            result['cpu'] = psutil.cpu_percent()
+            result['cpu'] = self.__get_cpu_percent()
 
         if 'bytes-recv' in self.metrics or 'bytes-sent' in self.metrics:
-            net = psutil.net_io_counters()
+            net = self.__get_net_counters()
             if net is not None:
                 tx_bytes = int((net.bytes_sent - self._net_counters.bytes_sent) / float(interval))
                 rx_bytes = int((net.bytes_recv - self._net_counters.bytes_recv) / float(interval))
@@ -316,17 +304,59 @@ class LocalMonitor(object):
 
         return result
 
+    def __get_mem_info(self):
+        try:
+            return psutil.virtual_memory().percent
+        except KeyError:
+            if not self._informed_on_mem_issue:
+                self.log.debug("Failed to get memory usage: %s", traceback.format_exc())
+                self.log.warning("Failed to get memory usage, use -v to get more detailed error info")
+                self._informed_on_mem_issue = True
+
     def __get_disk_counters(self):
         counters = None
         try:
             counters = psutil.disk_io_counters()
-        except RuntimeError as exc:
-            self.log.debug("Failed to get disk metrics: %s", exc)
+        except (RuntimeError, PermissionError) as exc:
+            self.log.debug("Failed to get disk io counters: %s", exc)
         if counters is None:
             counters = psutil._common.sdiskio(0, 0, 0, 0, 0, 0)  # pylint: disable=protected-access
             # noinspection PyProtectedMember
         return counters
 
+    def __get_net_counters(self):
+        counters = None
+        try:
+            counters = psutil.net_io_counters()
+        except (RuntimeError, PermissionError) as exc:
+            self.log.debug("Failed to get net io counters: %s", exc)
+        if counters is None:
+            counters = psutil._common.snetio(0, 0, 0, 0, 0, 0, 0, 0)  # pylint: disable=protected-access
+            # noinspection PyProtectedMember
+        return counters
+
+    def __get_disk_usage(self, path):
+        disk = None
+        try:
+            disk = psutil.disk_usage(path)
+        except (RuntimeError, PermissionError) as exc:
+            self.log.debug("Failed to get disk usage metrics: %s", exc)
+        if disk is None:
+            disk = psutil._common.sdiskusage(0, 0, 0, 0)  # pylint: disable=protected-access
+            # noinspection PyProtectedMember
+        return disk
+
+    def __get_cpu_percent(self):
+        cpu = None
+        try:
+            cpu = psutil.cpu_percent()
+        except (RuntimeError, PermissionError) as exc:
+            self.log.debug("Failed to get cpu percent metrics: %s", exc)
+        if cpu is None:
+            cpu = 0
+
+        return cpu
+
 
 class GraphiteClient(MonitoringClient):
     def __init__(self, parent_log, label, config, engine):
@@ -345,14 +375,11 @@ class GraphiteClient(MonitoringClient):
             self.host_label = self.address.replace('http://', '').replace('/', '').replace(':', '_')
 
         if self.config.get("logging", False):
-            if not PY3:
-                self.log.warning("Logging option doesn't work on python2.")
-            else:
-                self.logs_file = self.engine.create_artifact("Graphite_logs_{}".format(self.host_label), ".csv")
-                with open(self.logs_file, "a", newline='') as sa_logs:
-                    logs_writer = csv.writer(sa_logs, delimiter=',')
-                    metrics = ['ts'] + [metric for metric in self.config.get("metrics")]
-                    logs_writer.writerow(metrics)
+            self.logs_file = self.engine.create_artifact("Graphite_logs_{}".format(self.host_label), ".csv")
+            with open(self.logs_file, "a", newline='') as sa_logs:
+                logs_writer = csv.writer(sa_logs, delimiter=',')
+                metrics = ['ts'] + [metric for metric in self.config.get("metrics")]
+                logs_writer.writerow(metrics)
 
     def _get_url(self):
         exc = TaurusConfigError('Graphite client requires metrics list')
@@ -408,7 +435,7 @@ class GraphiteClient(MonitoringClient):
 
                 self._cached_data.append(item)
 
-            if self.logs_file and PY3:
+            if self.logs_file:
                 with open(self.logs_file, "a", newline='') as g_logs:
                     logs_writer = csv.writer(g_logs, delimiter=',')
                     logs_writer.writerow(data_line)
@@ -461,14 +488,11 @@ class ServerAgentClient(MonitoringClient):
             raise TaurusNetworkError(msg)
 
         if self.config.get("logging", False):
-            if not PY3:
-                self.log.warning("Logging option doesn't work on python2.")
-            else:
-                self.logs_file = self.engine.create_artifact("SAlogs_{}_{}".format(self.address, self.port), ".csv")
-                with open(self.logs_file, "a", newline='') as sa_logs:
-                    logs_writer = csv.writer(sa_logs, delimiter=',')
-                    metrics = ['ts'] + sorted([metric for metric in self._result_fields])
-                    logs_writer.writerow(metrics)
+            self.logs_file = self.engine.create_artifact("SAlogs_{}_{}".format(self.address, self.port), ".csv")
+            with open(self.logs_file, "a", newline='') as sa_logs:
+                logs_writer = csv.writer(sa_logs, delimiter=',')
+                metrics = ['ts'] + sorted([metric for metric in self._result_fields])
+                logs_writer.writerow(metrics)
 
     def disconnect(self):
         self.log.debug("Closing connection with agent at %s:%s...", self.address, self.port)
@@ -511,7 +535,7 @@ class ServerAgentClient(MonitoringClient):
                 item['source'] = source
                 res.append(item)
 
-                if self.logs_file and PY3:
+                if self.logs_file:
                     with open(self.logs_file, "a", newline='') as sa_logs:
                         line = [str(round(item['ts']))] + line[:-1].split("\t")
                         logs_writer = csv.writer(sa_logs, delimiter=',')
@@ -553,7 +577,7 @@ class MonitoringWidget(Pile, MonitoringListener, PrioritizedWidget):
                 for metric, value in iteritems(metrics):
                     if value[0] is None:
                         rendered = 'N/A'
-                    elif isinstance(value[0], integer_types):
+                    elif isinstance(value[0], int):
                         rendered = "{:,}".format(value[0])
                     elif isinstance(value[0], float):
                         rendered = "{:.3f}".format(value[0])
