@@ -32,8 +32,7 @@ from bzt.modules.aggregator import DataPoint, KPISet, AggregatorListener, Result
 from bzt.modules.blazemeter import BlazeMeterUploader, CloudProvisioning
 from bzt.modules.functional import FunctionalAggregatorListener
 from bzt.modules.passfail import PassFailStatus
-from bzt.six import etree, iteritems, string_types, integer_types
-from bzt.utils import get_full_path, is_windows
+from bzt.utils import etree, iteritems, get_full_path, is_windows
 
 if is_windows():
     from terminaltables import AsciiTable as SingleTable
@@ -97,12 +96,13 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
             self.__report_duration()
 
         if self.last_sec:
-            summary_kpi = self.last_sec[DataPoint.CUMULATIVE][""]
+            if '' in self.last_sec[DataPoint.CUMULATIVE]:
+                summary_kpi = self.last_sec[DataPoint.CUMULATIVE][""]
 
-            if self.parameters.get("summary", True):
-                self.__report_samples_count(summary_kpi)
-            if self.parameters.get("percentiles", True):
-                self.__report_percentiles(summary_kpi)
+                if self.parameters.get("summary", True):
+                    self.__report_samples_count(summary_kpi)
+                if self.parameters.get("percentiles", True):
+                    self.__report_percentiles(summary_kpi)
 
             if self.parameters.get("summary-labels", True):
                 self.__report_summary_labels(self.last_sec[DataPoint.CUMULATIVE])
@@ -176,7 +176,7 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
         for key in sorted(summary_kpi_set[KPISet.PERCENTILES].keys(), key=float):
             data.append((float(key), summary_kpi_set[KPISet.PERCENTILES][key]))
             # self.log.info("Percentile %.1f%%: %.3f", )
-        table = SingleTable(data) if sys.stdout.isatty() else AsciiTable(data)
+        table = SingleTable(data) if sys.stdout and sys.stdout.isatty() else AsciiTable(data)
         table.justify_columns[0] = 'right'
         table.justify_columns[1] = 'right'
         self.log.info("Percentiles:\n%s", table.table)
@@ -193,9 +193,6 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
                 if failed_samples_count:
                     self.log.info(report_template, failed_samples_count, sample_label)
 
-    def __console_safe_encode(self, text):
-        return text.encode(locale.getpreferredencoding(), errors='replace').decode('unicode_escape')
-
     def __get_sample_element(self, sample, label_name):
         failed_samples_count = sample['fail']
         success_samples_count = sample['succ']
@@ -205,10 +202,10 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
 
         errors = set()
         for err_desc in sample['errors']:
-            errors.add(self.__console_safe_encode(err_desc["msg"]))
+            errors.add(err_desc["msg"])
 
         return (
-            self.__console_safe_encode(label_name),
+            label_name,
             "FAIL" if failed_samples_count > 0 else "OK",
             "{0:.2f}%".format(round(success_samples_perc, 2)),
             "{0:.3f}".format(round(sample['avg_rt'], 3)),
@@ -223,7 +220,7 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
         for sample_label in sorted_labels:
             if sample_label != "":
                 data.append(self.__get_sample_element(cumulative[sample_label], sample_label))
-        table = SingleTable(data) if sys.stdout.isatty() else AsciiTable(data)
+        table = SingleTable(data) if sys.stdout and sys.stdout.isatty() else AsciiTable(data)
         table.justify_columns = justify
         self.log.info("Request label stats:\n%s", table.table)
 
@@ -292,9 +289,9 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
     def __val_to_str(self, kpi_val):
         if isinstance(kpi_val, float):
             return '%.5f' % kpi_val
-        elif isinstance(kpi_val, integer_types):
+        elif isinstance(kpi_val, int):
             return '%d' % kpi_val
-        elif isinstance(kpi_val, string_types):
+        elif isinstance(kpi_val, str):
             return kpi_val
         else:
             raise TaurusInternalException("Unhandled kpi type: %s" % type(kpi_val))
@@ -303,11 +300,12 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
         self.log.info("Dumping final status as CSV: %s", filename)
         # FIXME: what if there's no last_sec
         with open(get_full_path(filename), 'wt') as fhd:
-            fieldnames = self.__get_csv_dict('', self.last_sec[DataPoint.CUMULATIVE]['']).keys()
-            writer = csv.DictWriter(fhd, fieldnames)
-            writer.writeheader()
-            for label, kpiset in iteritems(self.last_sec[DataPoint.CUMULATIVE]):
-                writer.writerow(self.__get_csv_dict(label, kpiset))
+            if '' in self.last_sec[DataPoint.CUMULATIVE]:
+                fieldnames = self.__get_csv_dict('', self.last_sec[DataPoint.CUMULATIVE]['']).keys()
+                writer = csv.DictWriter(fhd, fieldnames)
+                writer.writeheader()
+                for label, kpiset in iteritems(self.last_sec[DataPoint.CUMULATIVE]):
+                    writer.writerow(self.__get_csv_dict(label, kpiset))
 
     def __get_csv_dict(self, label, kpiset):
         kpi_copy = copy.deepcopy(kpiset)
@@ -558,7 +556,7 @@ class XUnitFileWriter(object):
     def report_test_suite(self, suite_name):
         """
         :type suite_name: str
-        :type children: list[bzt.six.etree.Element]
+        :type children: list[lxml.etree.Element]
         """
         self.add_test_suite(suite_name, attributes={"name": suite_name, "package_name": "bzt"})
 
@@ -566,7 +564,7 @@ class XUnitFileWriter(object):
         """
         :type suite_name: str
         :type case_name: str
-        :type children: list[bzt.six.etree.Element]
+        :type children: list[lxml.etree.Element]
         """
         children = children or []
         if self.report_urls:
